export

Macro export 

macro_rules! export {
    ($name:literal, $plugin:ty) => { ... };
}
Export a Plugin as the component’s plugin resource when the crate is built for wasm32: the resource’s new deserializes the options string into Plugin::Options and calls Plugin::new, and its classify and mutate call the instance. Built for anything else it exposes its name and constructor as DIFFR_PLUGIN for the host registry.