Module native

Module native 

Native registrations contributed by linked plugin crates.

Structs

Registration
A name and constructor, registered without instantiating the plugin.

Traits

Instance
The object-safe form of a plugin, after its options have been deserialized.